#include "sbbzlib.h"

SB_PHP_FUNCTION(SBBzlib, AssertH)
{
	long l4Err_Code;
	zend_bool bCondition;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "bl", &bCondition, &l4Err_Code) == SUCCESS)
	{
		SBCheckError(SBBzlib_AssertH((int8_t)bCondition, (int32_t)l4Err_Code) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(bool, integer)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBBzlib, AssertD)
{
	char *sErr_Text;
	int sErr_Text_len;
	zend_bool bCondition;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "bs", &bCondition, &sErr_Text, &sErr_Text_len) == SUCCESS)
	{
		SBCheckError(SBBzlib_AssertD((int8_t)bCondition, sErr_Text, (int32_t)sErr_Text_len) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(bool, string)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBBzlib, BZ2_indexIntoF)
{
	long l4indx;
	SBArrayZValInfo aicftab;
	uint32_t _err;
	zval *zacftab;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "lz", &l4indx, &zacftab) == SUCCESS) && PZVAL_IS_REF(zacftab) && (IS_ARRAY == Z_TYPE_P(zacftab)))
	{
		int32_t l4OutResultRaw = 0;
		if (!SBGetInt32ArrayFromZVal(zacftab, &aicftab TSRMLS_CC)) RETURN_FALSE;
		_err = SBBzlib_BZ2_indexIntoF((int32_t)l4indx, aicftab.data, &aicftab.len, &l4OutResultRaw);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			SBResizeArrayZVal(&aicftab TSRMLS_CC);
			SBCheckError(SBGetLastReturnBuffer(511896834, 1, aicftab.data, &aicftab.len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBFreeArrayZValInfo(&aicftab);
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		SBSetInt32ArrayToZVal(&aicftab, zacftab);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("(integer, &array of int32)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBBzlib, BZ2_bzCompressInit)
{
	long l4blockSize100k;
	long l4verbosity;
	long l4workFactor;
	zval *ostrm;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!lll", &ostrm, bz_stream_ce_ptr, &l4blockSize100k, &l4verbosity, &l4workFactor) == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(SBBzlib_BZ2_bzCompressInit(SBGetObjectHandle(ostrm TSRMLS_CC), (int32_t)l4blockSize100k, (int32_t)l4verbosity, (int32_t)l4workFactor, &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("(bz_stream, integer, integer, integer)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBBzlib, BZ2_bzCompress)
{
	long l4action;
	zval *ostrm;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!l", &ostrm, bz_stream_ce_ptr, &l4action) == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(SBBzlib_BZ2_bzCompress(SBGetObjectHandle(ostrm TSRMLS_CC), (int32_t)l4action, &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("(bz_stream, integer)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBBzlib, BZ2_bzCompressEnd)
{
	zval *ostrm;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &ostrm, bz_stream_ce_ptr) == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(SBBzlib_BZ2_bzCompressEnd(SBGetObjectHandle(ostrm TSRMLS_CC), &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("(bz_stream)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBBzlib, BZ2_bzDecompressInit)
{
	long l4verbosity;
	zend_bool bSmall;
	zval *ostrm;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!lb", &ostrm, bz_stream_ce_ptr, &l4verbosity, &bSmall) == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(SBBzlib_BZ2_bzDecompressInit(SBGetObjectHandle(ostrm TSRMLS_CC), (int32_t)l4verbosity, (int8_t)bSmall, &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("(bz_stream, integer, bool)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBBzlib, BZ2_bzDecompress)
{
	zval *ostrm;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &ostrm, bz_stream_ce_ptr) == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(SBBzlib_BZ2_bzDecompress(SBGetObjectHandle(ostrm TSRMLS_CC), &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("(bz_stream)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBBzlib, BZ2_bzDecompressEnd)
{
	zval *ostrm;
	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!", &ostrm, bz_stream_ce_ptr) == SUCCESS)
	{
		int32_t l4OutResultRaw = 0;
		SBCheckError(SBBzlib_BZ2_bzDecompressEnd(SBGetObjectHandle(ostrm TSRMLS_CC), &l4OutResultRaw) TSRMLS_CC);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("(bz_stream)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBBzlib, BZ2_bzBuffToBuffCompress)
{
	long l4blockSize100k;
	long l4verbosity;
	long l4workFactor;
	long u4sourceLen;
	uint32_t u4destLenRaw;
	zval *odest;
	zval *osource;
	zval *zu4destLen;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!zO!llll", &odest, TSBByteArray_ce_ptr, &zu4destLen, &osource, TSBByteArray_ce_ptr, &u4sourceLen, &l4blockSize100k, &l4verbosity, &l4workFactor) == SUCCESS) && PZVAL_IS_REF(zu4destLen) && (IS_LONG == Z_TYPE_P(zu4destLen)))
	{
		int32_t l4OutResultRaw = 0;
		u4destLenRaw = (uint32_t)Z_LVAL_P(zu4destLen);
		SBCheckError(SBBzlib_BZ2_bzBuffToBuffCompress(SBGetObjectHandle(odest TSRMLS_CC), &u4destLenRaw, SBGetObjectHandle(osource TSRMLS_CC), (uint32_t)u4sourceLen, (int32_t)l4blockSize100k, (int32_t)l4verbosity, (int32_t)l4workFactor, &l4OutResultRaw) TSRMLS_CC);
		ZVAL_LONG(zu4destLen, (long)u4destLenRaw);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("(TSBByteArray, &integer, TSBByteArray, integer, integer, integer, integer)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBBzlib, BZ2_bzBuffToBuffDecompress)
{
	long l4verbosity;
	long u4sourceLen;
	uint32_t u4destLenRaw;
	zend_bool bSmall;
	zval *odest;
	zval *osource;
	zval *zu4destLen;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O!zO!lbl", &odest, TSBByteArray_ce_ptr, &zu4destLen, &osource, TSBByteArray_ce_ptr, &u4sourceLen, &bSmall, &l4verbosity) == SUCCESS) && PZVAL_IS_REF(zu4destLen) && (IS_LONG == Z_TYPE_P(zu4destLen)))
	{
		int32_t l4OutResultRaw = 0;
		u4destLenRaw = (uint32_t)Z_LVAL_P(zu4destLen);
		SBCheckError(SBBzlib_BZ2_bzBuffToBuffDecompress(SBGetObjectHandle(odest TSRMLS_CC), &u4destLenRaw, SBGetObjectHandle(osource TSRMLS_CC), (uint32_t)u4sourceLen, (int8_t)bSmall, (int32_t)l4verbosity, &l4OutResultRaw) TSRMLS_CC);
		ZVAL_LONG(zu4destLen, (long)u4destLenRaw);
		RETURN_LONG((long)l4OutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("(TSBByteArray, &integer, TSBByteArray, integer, bool, integer)" TSRMLS_CC);
	}
}

