#include "sbchacha20.h"

SB_PHP_METHOD(TSBChaCha20State, __construct)
{
	if (ZEND_NUM_ARGS() == 0)
	{
		php_sbb_struct * intern = (php_sbb_struct *)zend_object_store_get_object(getThis() TSRMLS_CC);
		intern->data = emalloc(sizeof(TSBChaCha20State));
		intern->len = sizeof(TSBChaCha20State);
		intern->ownData = 1;
	}
	else
		ZEND_WRONG_PARAM_COUNT();
}

SB_PHP_METHOD(TSBChaCha20State, getSizeOf)
{
	if (ZEND_NUM_ARGS() > 0)
		ZEND_WRONG_PARAM_COUNT();

	RETURN_LONG(sizeof(TSBChaCha20State));
}

zend_class_entry *TSBChaCha20State_ce_ptr = NULL;

static zend_function_entry TSBChaCha20State_methods[] = {
	PHP_ME(TSBChaCha20State, __construct, NULL, ZEND_ACC_PUBLIC)
	PHP_ME(TSBChaCha20State, getSizeOf, NULL, ZEND_ACC_PUBLIC | ZEND_ACC_STATIC)
	PHP_FE_END
};

void Register_TSBChaCha20State(TSRMLS_D)
{
	zend_class_entry ce;
	if (TSBChaCha20State_ce_ptr != NULL)
		return;
	INIT_CLASS_ENTRY(ce, "TSBChaCha20State", TSBChaCha20State_methods);
	TSBChaCha20State_ce_ptr = zend_register_internal_class_ex(&ce, TSBBaseStruct_ce_ptr, NULL TSRMLS_CC);
}

SB_PHP_FUNCTION(SBChaCha20, QuarterRound)
{
	long l4a;
	long l4b;
	long l4c;
	long l4d;
	zval *oState;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "llllO", &l4a, &l4b, &l4c, &l4d, &oState, TSBChaCha20State_ce_ptr) == SUCCESS) && PZVAL_IS_REF(oState))
	{
		SBCheckError(SBChaCha20_QuarterRound((int32_t)l4a, (int32_t)l4b, (int32_t)l4c, (int32_t)l4d, (TSBChaCha20State *)SBGetStructPointer(oState TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(integer, integer, integer, integer, &TSBChaCha20State)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBChaCha20, InnerBlock)
{
	zval *oState;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "O", &oState, TSBChaCha20State_ce_ptr) == SUCCESS) && PZVAL_IS_REF(oState))
	{
		SBCheckError(SBChaCha20_InnerBlock((TSBChaCha20State *)SBGetStructPointer(oState TSRMLS_CC)) TSRMLS_CC);
	}
	else
	{
		SBErrorExpectsArguments("(&TSBChaCha20State)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBChaCha20, ChaCha20Block)
{
	long u4Counter;
	SBArrayZValInfo aiKey;
	SBArrayZValInfo aiNonce;
	uint32_t _err;
	zval *zaKey;
	zval *zaNonce;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "zzl", &zaKey, &zaNonce, &u4Counter) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zaKey)) || (IS_ARRAY == Z_TYPE_P(zaKey)) || (IS_NULL == Z_TYPE_P(zaKey))) && ((IS_STRING == Z_TYPE_P(zaNonce)) || (IS_ARRAY == Z_TYPE_P(zaNonce)) || (IS_NULL == Z_TYPE_P(zaNonce))))
	{
		uint8_t *u8OutResult = NULL;
		int32_t u8OutResult_len = 0;
		if (!SBGetByteArrayFromZVal(zaKey, &aiKey TSRMLS_CC)) RETURN_FALSE;
		if (!SBGetByteArrayFromZVal(zaNonce, &aiNonce TSRMLS_CC)) RETURN_FALSE;
		_err = SBChaCha20_ChaCha20Block(aiKey.data, aiKey.len, aiNonce.data, aiNonce.len, (uint32_t)u4Counter, u8OutResult, &u8OutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			u8OutResult = emalloc(u8OutResult_len + 1);
			SBCheckError(SBGetLastReturnBuffer(1503672178, 3, u8OutResult, &u8OutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		SBFreeArrayZValInfo(&aiKey);
		SBFreeArrayZValInfo(&aiNonce);
		if (NULL == u8OutResult) u8OutResult = emalloc(1);
		u8OutResult[u8OutResult_len] = 0;
		RETURN_STRINGL(u8OutResult, u8OutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("(array of byte|string|NULL, array of byte|string|NULL, integer)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBChaCha20, ChaCha20Encrypt)
{
	long u4Counter;
	SBArrayZValInfo aiKey;
	SBArrayZValInfo aiMsg;
	SBArrayZValInfo aiNonce;
	uint32_t _err;
	zval *zaKey;
	zval *zaMsg;
	zval *zaNonce;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "zzlz", &zaKey, &zaNonce, &u4Counter, &zaMsg) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zaKey)) || (IS_ARRAY == Z_TYPE_P(zaKey)) || (IS_NULL == Z_TYPE_P(zaKey))) && ((IS_STRING == Z_TYPE_P(zaNonce)) || (IS_ARRAY == Z_TYPE_P(zaNonce)) || (IS_NULL == Z_TYPE_P(zaNonce))) && ((IS_STRING == Z_TYPE_P(zaMsg)) || (IS_ARRAY == Z_TYPE_P(zaMsg)) || (IS_NULL == Z_TYPE_P(zaMsg))))
	{
		uint8_t *u8OutResult = NULL;
		int32_t u8OutResult_len = 0;
		if (!SBGetByteArrayFromZVal(zaKey, &aiKey TSRMLS_CC)) RETURN_FALSE;
		if (!SBGetByteArrayFromZVal(zaNonce, &aiNonce TSRMLS_CC)) RETURN_FALSE;
		if (!SBGetByteArrayFromZVal(zaMsg, &aiMsg TSRMLS_CC)) RETURN_FALSE;
		_err = SBChaCha20_ChaCha20Encrypt(aiKey.data, aiKey.len, aiNonce.data, aiNonce.len, (uint32_t)u4Counter, aiMsg.data, aiMsg.len, u8OutResult, &u8OutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			u8OutResult = emalloc(u8OutResult_len + 1);
			SBCheckError(SBGetLastReturnBuffer(-946546312, 4, u8OutResult, &u8OutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		SBFreeArrayZValInfo(&aiKey);
		SBFreeArrayZValInfo(&aiNonce);
		SBFreeArrayZValInfo(&aiMsg);
		if (NULL == u8OutResult) u8OutResult = emalloc(1);
		u8OutResult[u8OutResult_len] = 0;
		RETURN_STRINGL(u8OutResult, u8OutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("(array of byte|string|NULL, array of byte|string|NULL, integer, array of byte|string|NULL)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBChaCha20, ChaCha20Decrypt)
{
	long u4Counter;
	SBArrayZValInfo aiKey;
	SBArrayZValInfo aiMsg;
	SBArrayZValInfo aiNonce;
	uint32_t _err;
	zval *zaKey;
	zval *zaMsg;
	zval *zaNonce;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "zzlz", &zaKey, &zaNonce, &u4Counter, &zaMsg) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zaKey)) || (IS_ARRAY == Z_TYPE_P(zaKey)) || (IS_NULL == Z_TYPE_P(zaKey))) && ((IS_STRING == Z_TYPE_P(zaNonce)) || (IS_ARRAY == Z_TYPE_P(zaNonce)) || (IS_NULL == Z_TYPE_P(zaNonce))) && ((IS_STRING == Z_TYPE_P(zaMsg)) || (IS_ARRAY == Z_TYPE_P(zaMsg)) || (IS_NULL == Z_TYPE_P(zaMsg))))
	{
		uint8_t *u8OutResult = NULL;
		int32_t u8OutResult_len = 0;
		if (!SBGetByteArrayFromZVal(zaKey, &aiKey TSRMLS_CC)) RETURN_FALSE;
		if (!SBGetByteArrayFromZVal(zaNonce, &aiNonce TSRMLS_CC)) RETURN_FALSE;
		if (!SBGetByteArrayFromZVal(zaMsg, &aiMsg TSRMLS_CC)) RETURN_FALSE;
		_err = SBChaCha20_ChaCha20Decrypt(aiKey.data, aiKey.len, aiNonce.data, aiNonce.len, (uint32_t)u4Counter, aiMsg.data, aiMsg.len, u8OutResult, &u8OutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			u8OutResult = emalloc(u8OutResult_len + 1);
			SBCheckError(SBGetLastReturnBuffer(2003403102, 4, u8OutResult, &u8OutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		SBFreeArrayZValInfo(&aiKey);
		SBFreeArrayZValInfo(&aiNonce);
		SBFreeArrayZValInfo(&aiMsg);
		if (NULL == u8OutResult) u8OutResult = emalloc(1);
		u8OutResult[u8OutResult_len] = 0;
		RETURN_STRINGL(u8OutResult, u8OutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("(array of byte|string|NULL, array of byte|string|NULL, integer, array of byte|string|NULL)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBChaCha20, Poly1305KeyGen)
{
	SBArrayZValInfo aiKey;
	SBArrayZValInfo aiNonce;
	uint32_t _err;
	zval *zaKey;
	zval *zaNonce;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "zz", &zaKey, &zaNonce) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zaKey)) || (IS_ARRAY == Z_TYPE_P(zaKey)) || (IS_NULL == Z_TYPE_P(zaKey))) && ((IS_STRING == Z_TYPE_P(zaNonce)) || (IS_ARRAY == Z_TYPE_P(zaNonce)) || (IS_NULL == Z_TYPE_P(zaNonce))))
	{
		uint8_t *u8OutResult = NULL;
		int32_t u8OutResult_len = 0;
		if (!SBGetByteArrayFromZVal(zaKey, &aiKey TSRMLS_CC)) RETURN_FALSE;
		if (!SBGetByteArrayFromZVal(zaNonce, &aiNonce TSRMLS_CC)) RETURN_FALSE;
		_err = SBChaCha20_Poly1305KeyGen(aiKey.data, aiKey.len, aiNonce.data, aiNonce.len, u8OutResult, &u8OutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			u8OutResult = emalloc(u8OutResult_len + 1);
			SBCheckError(SBGetLastReturnBuffer(527109665, 2, u8OutResult, &u8OutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		SBFreeArrayZValInfo(&aiKey);
		SBFreeArrayZValInfo(&aiNonce);
		if (NULL == u8OutResult) u8OutResult = emalloc(1);
		u8OutResult[u8OutResult_len] = 0;
		RETURN_STRINGL(u8OutResult, u8OutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("(array of byte|string|NULL, array of byte|string|NULL)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBChaCha20, AEADEncrypt)
{
	long fMode;
	SBArrayZValInfo aiAAD;
	SBArrayZValInfo aiKey;
	SBArrayZValInfo aiMsg;
	SBArrayZValInfo aiNonce;
	uint32_t _err;
	zval *oTag;
	zval *zaAAD;
	zval *zaKey;
	zval *zaMsg;
	zval *zaNonce;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "zzzzlO", &zaKey, &zaNonce, &zaMsg, &zaAAD, &fMode, &oTag, TSBPoly1305Tag_ce_ptr) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zaKey)) || (IS_ARRAY == Z_TYPE_P(zaKey)) || (IS_NULL == Z_TYPE_P(zaKey))) && ((IS_STRING == Z_TYPE_P(zaNonce)) || (IS_ARRAY == Z_TYPE_P(zaNonce)) || (IS_NULL == Z_TYPE_P(zaNonce))) && ((IS_STRING == Z_TYPE_P(zaMsg)) || (IS_ARRAY == Z_TYPE_P(zaMsg)) || (IS_NULL == Z_TYPE_P(zaMsg))) && ((IS_STRING == Z_TYPE_P(zaAAD)) || (IS_ARRAY == Z_TYPE_P(zaAAD)) || (IS_NULL == Z_TYPE_P(zaAAD))) && PZVAL_IS_REF(oTag))
	{
		uint8_t *u8OutResult = NULL;
		int32_t u8OutResult_len = 0;
		if (!SBGetByteArrayFromZVal(zaKey, &aiKey TSRMLS_CC)) RETURN_FALSE;
		if (!SBGetByteArrayFromZVal(zaNonce, &aiNonce TSRMLS_CC)) RETURN_FALSE;
		if (!SBGetByteArrayFromZVal(zaMsg, &aiMsg TSRMLS_CC)) RETURN_FALSE;
		if (!SBGetByteArrayFromZVal(zaAAD, &aiAAD TSRMLS_CC)) RETURN_FALSE;
		_err = SBChaCha20_AEADEncrypt(aiKey.data, aiKey.len, aiNonce.data, aiNonce.len, aiMsg.data, aiMsg.len, aiAAD.data, aiAAD.len, (TSBPoly1305ModeRaw)fMode, (TSBPoly1305Tag *)SBGetStructPointer(oTag TSRMLS_CC), u8OutResult, &u8OutResult_len);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			u8OutResult = emalloc(u8OutResult_len + 1);
			SBCheckError(SBGetLastReturnBuffer(475517173, 6, u8OutResult, &u8OutResult_len) TSRMLS_CC);
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		SBFreeArrayZValInfo(&aiKey);
		SBFreeArrayZValInfo(&aiNonce);
		SBFreeArrayZValInfo(&aiMsg);
		SBFreeArrayZValInfo(&aiAAD);
		if (NULL == u8OutResult) u8OutResult = emalloc(1);
		u8OutResult[u8OutResult_len] = 0;
		RETURN_STRINGL(u8OutResult, u8OutResult_len, 0);
	}
	else
	{
		SBErrorExpectsArguments("(array of byte|string|NULL, array of byte|string|NULL, array of byte|string|NULL, array of byte|string|NULL, integer, &TSBPoly1305Tag)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBChaCha20, AEADDecrypt)
{
	long fMode;
	SBArrayZValInfo aiAAD;
	SBArrayZValInfo aiDMsg;
	SBArrayZValInfo aiEMsg;
	SBArrayZValInfo aiKey;
	SBArrayZValInfo aiNonce;
	uint32_t _err;
	zval *oTag;
	zval *zaAAD;
	zval *zaDMsg;
	zval *zaEMsg;
	zval *zaKey;
	zval *zaNonce;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "zzzzOlz", &zaKey, &zaNonce, &zaEMsg, &zaAAD, &oTag, TSBPoly1305Tag_ce_ptr, &fMode, &zaDMsg) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zaKey)) || (IS_ARRAY == Z_TYPE_P(zaKey)) || (IS_NULL == Z_TYPE_P(zaKey))) && ((IS_STRING == Z_TYPE_P(zaNonce)) || (IS_ARRAY == Z_TYPE_P(zaNonce)) || (IS_NULL == Z_TYPE_P(zaNonce))) && ((IS_STRING == Z_TYPE_P(zaEMsg)) || (IS_ARRAY == Z_TYPE_P(zaEMsg)) || (IS_NULL == Z_TYPE_P(zaEMsg))) && ((IS_STRING == Z_TYPE_P(zaAAD)) || (IS_ARRAY == Z_TYPE_P(zaAAD)) || (IS_NULL == Z_TYPE_P(zaAAD))) && PZVAL_IS_REF(zaDMsg) && ((IS_STRING == Z_TYPE_P(zaDMsg)) || (IS_ARRAY == Z_TYPE_P(zaDMsg))))
	{
		int8_t bOutResultRaw = 0;
		if (!SBGetByteArrayFromZVal(zaKey, &aiKey TSRMLS_CC)) RETURN_FALSE;
		if (!SBGetByteArrayFromZVal(zaNonce, &aiNonce TSRMLS_CC)) RETURN_FALSE;
		if (!SBGetByteArrayFromZVal(zaEMsg, &aiEMsg TSRMLS_CC)) RETURN_FALSE;
		if (!SBGetByteArrayFromZVal(zaAAD, &aiAAD TSRMLS_CC)) RETURN_FALSE;
		if (!SBGetByteArrayFromZVal(zaDMsg, &aiDMsg TSRMLS_CC)) RETURN_FALSE;
		_err = SBChaCha20_AEADDecrypt(aiKey.data, aiKey.len, aiNonce.data, aiNonce.len, aiEMsg.data, aiEMsg.len, aiAAD.data, aiAAD.len, (TSBPoly1305Tag *)SBGetStructPointer(oTag TSRMLS_CC), (TSBPoly1305ModeRaw)fMode, aiDMsg.data, &aiDMsg.len, &bOutResultRaw);
		if (SB_ERROR_INSUFFICIENT_BUFFER_SIZE == _err)
		{
			SBDetachDataFromZValAndResize(zaDMsg, &aiDMsg TSRMLS_CC);
			SBCheckError(SBGetLastReturnBuffer(-536313408, 6, aiDMsg.data, &aiDMsg.len) TSRMLS_CC);
			((char *)aiDMsg.data)[aiDMsg.len] = 0;
		}
		else
		if (_err != SB_ERROR_OK)
		{
			SBFreeArrayZValInfo(&aiDMsg);
			SBThrowException(_err TSRMLS_CC);
			RETURN_FALSE;
		}
	
		SBFreeArrayZValInfo(&aiKey);
		SBFreeArrayZValInfo(&aiNonce);
		SBFreeArrayZValInfo(&aiEMsg);
		SBFreeArrayZValInfo(&aiAAD);
		SBSetByteArrayToZVal(&aiDMsg, zaDMsg);
		RETURN_BOOL(bOutResultRaw);
	}
	else
	{
		SBErrorExpectsArguments("(array of byte|string|NULL, array of byte|string|NULL, array of byte|string|NULL, array of byte|string|NULL, TSBPoly1305Tag, integer, &array of byte|string)" TSRMLS_CC);
	}
}

void Register_SBChaCha20_Constants(int module_number TSRMLS_DC)
{
	SB_REGISTER_LONG_CONSTANT(SBChaCha20, TChaCha20KeySize, SB_TChaCha20KeySize, SB_TChaCha20KeySize);
	SB_REGISTER_LONG_CONSTANT(SBChaCha20, TChaCha20NonceSize, SB_TChaCha20NonceSize, SB_TChaCha20NonceSize);
	SB_REGISTER_LONG_CONSTANT(SBChaCha20, TChaCha20StateSize, SB_TChaCha20StateSize, SB_TChaCha20StateSize);
}

