#include "sbdes.h"

SB_PHP_METHOD(TDESExpandedKey, __construct)
{
	if (ZEND_NUM_ARGS() == 0)
	{
		php_sbb_struct * intern = (php_sbb_struct *)zend_object_store_get_object(getThis() TSRMLS_CC);
		intern->data = emalloc(sizeof(TDESExpandedKey));
		intern->len = sizeof(TDESExpandedKey);
		intern->ownData = 1;
	}
	else
		ZEND_WRONG_PARAM_COUNT();
}

SB_PHP_METHOD(TDESExpandedKey, getSizeOf)
{
	if (ZEND_NUM_ARGS() > 0)
		ZEND_WRONG_PARAM_COUNT();

	RETURN_LONG(sizeof(TDESExpandedKey));
}

zend_class_entry *TDESExpandedKey_ce_ptr = NULL;

static zend_function_entry TDESExpandedKey_methods[] = {
	PHP_ME(TDESExpandedKey, __construct, NULL, ZEND_ACC_PUBLIC)
	PHP_ME(TDESExpandedKey, getSizeOf, NULL, ZEND_ACC_PUBLIC | ZEND_ACC_STATIC)
	PHP_FE_END
};

void Register_TDESExpandedKey(TSRMLS_D)
{
	zend_class_entry ce;
	if (TDESExpandedKey_ce_ptr != NULL)
		return;
	INIT_CLASS_ENTRY(ce, "TDESExpandedKey", TDESExpandedKey_methods);
	TDESExpandedKey_ce_ptr = zend_register_internal_class_ex(&ce, TSBBaseStruct_ce_ptr, NULL TSRMLS_CC);
}

SB_PHP_FUNCTION(SBDES, ExpandKeyForEncryption)
{
	SBArrayZValInfo aiKey;
	zval *oExpandedKey;
	zval *zaKey;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "zO", &zaKey, &oExpandedKey, TDESExpandedKey_ce_ptr) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zaKey)) || (IS_ARRAY == Z_TYPE_P(zaKey)) || (IS_NULL == Z_TYPE_P(zaKey))) && PZVAL_IS_REF(oExpandedKey))
	{
		if (!SBGetByteArrayFromZVal(zaKey, &aiKey TSRMLS_CC)) RETURN_FALSE;
		SBCheckError(SBDES_ExpandKeyForEncryption(aiKey.data, aiKey.len, (TDESExpandedKey *)SBGetStructPointer(oExpandedKey TSRMLS_CC)) TSRMLS_CC);
		SBFreeArrayZValInfo(&aiKey);
	}
	else
	{
		SBErrorExpectsArguments("(array of byte|string|NULL, &TDESExpandedKey)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBDES, ExpandKeyForDecryption)
{
	SBArrayZValInfo aiKey;
	zval *oExpandedKey;
	zval *zaKey;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "zO", &zaKey, &oExpandedKey, TDESExpandedKey_ce_ptr) == SUCCESS) && ((IS_STRING == Z_TYPE_P(zaKey)) || (IS_ARRAY == Z_TYPE_P(zaKey)) || (IS_NULL == Z_TYPE_P(zaKey))) && PZVAL_IS_REF(oExpandedKey))
	{
		if (!SBGetByteArrayFromZVal(zaKey, &aiKey TSRMLS_CC)) RETURN_FALSE;
		SBCheckError(SBDES_ExpandKeyForDecryption(aiKey.data, aiKey.len, (TDESExpandedKey *)SBGetStructPointer(oExpandedKey TSRMLS_CC)) TSRMLS_CC);
		SBFreeArrayZValInfo(&aiKey);
	}
	else
	{
		SBErrorExpectsArguments("(array of byte|string|NULL, &TDESExpandedKey)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBDES, Encrypt)
{
	uint32_t u4B0Raw;
	uint32_t u4B1Raw;
	zval *oExpandedKey;
	zval *zu4B0;
	zval *zu4B1;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "zzO", &zu4B0, &zu4B1, &oExpandedKey, TDESExpandedKey_ce_ptr) == SUCCESS) && PZVAL_IS_REF(zu4B0) && (IS_LONG == Z_TYPE_P(zu4B0)) && PZVAL_IS_REF(zu4B1) && (IS_LONG == Z_TYPE_P(zu4B1)))
	{
		u4B0Raw = (uint32_t)Z_LVAL_P(zu4B0);
		u4B1Raw = (uint32_t)Z_LVAL_P(zu4B1);
		SBCheckError(SBDES_Encrypt(&u4B0Raw, &u4B1Raw, (TDESExpandedKey *)SBGetStructPointer(oExpandedKey TSRMLS_CC)) TSRMLS_CC);
		ZVAL_LONG(zu4B0, (long)u4B0Raw);
		ZVAL_LONG(zu4B1, (long)u4B1Raw);
	}
	else
	{
		SBErrorExpectsArguments("(&integer, &integer, TDESExpandedKey)" TSRMLS_CC);
	}
}

SB_PHP_FUNCTION(SBDES, EncryptEDE)
{
	uint32_t u4B0Raw;
	uint32_t u4B1Raw;
	zval *oKey1;
	zval *oKey2;
	zval *oKey3;
	zval *zu4B0;
	zval *zu4B1;
	if ((zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "zzOOO", &zu4B0, &zu4B1, &oKey1, TDESExpandedKey_ce_ptr, &oKey2, TDESExpandedKey_ce_ptr, &oKey3, TDESExpandedKey_ce_ptr) == SUCCESS) && PZVAL_IS_REF(zu4B0) && (IS_LONG == Z_TYPE_P(zu4B0)) && PZVAL_IS_REF(zu4B1) && (IS_LONG == Z_TYPE_P(zu4B1)))
	{
		u4B0Raw = (uint32_t)Z_LVAL_P(zu4B0);
		u4B1Raw = (uint32_t)Z_LVAL_P(zu4B1);
		SBCheckError(SBDES_EncryptEDE(&u4B0Raw, &u4B1Raw, (TDESExpandedKey *)SBGetStructPointer(oKey1 TSRMLS_CC), (TDESExpandedKey *)SBGetStructPointer(oKey2 TSRMLS_CC), (TDESExpandedKey *)SBGetStructPointer(oKey3 TSRMLS_CC)) TSRMLS_CC);
		ZVAL_LONG(zu4B0, (long)u4B0Raw);
		ZVAL_LONG(zu4B1, (long)u4B1Raw);
	}
	else
	{
		SBErrorExpectsArguments("(&integer, &integer, TDESExpandedKey, TDESExpandedKey, TDESExpandedKey)" TSRMLS_CC);
	}
}

void Register_SBDES_Constants(int module_number TSRMLS_DC)
{
	SB_REGISTER_LONG_CONSTANT(SBDES, TDESBufferSize, SB_TDESBufferSize, SB_TDESBufferSize);
	SB_REGISTER_LONG_CONSTANT(SBDES, TDESKeySize, SB_TDESKeySize, SB_TDESKeySize);
	SB_REGISTER_LONG_CONSTANT(SBDES, TDESExpandedKeySize, SB_TDESExpandedKeySize, SB_TDESExpandedKeySize);
	SB_REGISTER_LONG_CONSTANT(SBDES, T3DESBufferSize, SB_T3DESBufferSize, SB_T3DESBufferSize);
	SB_REGISTER_LONG_CONSTANT(SBDES, T3DESKeySize, SB_T3DESKeySize, SB_T3DESKeySize);
	SB_REGISTER_LONG_CONSTANT(SBDES, T3DESExpandedKeySize, SB_T3DESExpandedKeySize, SB_T3DESExpandedKeySize);
}

