<?php 
    date_default_timezone_set("UTC");

    define("ACTION_UNKNOWN",        -1);
    define("ACTION_SMIME_SIGN",      0);
    define("ACTION_SMIME_VERIFY",    1);
    define("ACTION_SMIME_ENCRYPT",   2);
    define("ACTION_SMIME_DECRYPT",   3);
    define("ACTION_PGPMIME_SIGN",    4);
    define("ACTION_PGPMIME_VERIFY",  5);
    define("ACTION_PGPMIME_ENCRYPT", 6);
    define("ACTION_PGPMIME_DECRYPT", 7);

    $action = ACTION_UNKNOWN;
    $filename = "";
    $inputtemp = "";
    $certtemp= "";
    $keytemp = "";
    $certpass = "";
    $keypass = "";
    $encalg = -1;
    $hash = -1;
    $certstorage = new TElMemoryCertStorage(NULL);
    $keyring = new TElPGPKeyring(NULL);
    $passtry = false;

    function PGPMIMEKeyPassphrase($Sender, $Key, &$Passphrase, &$Cancel)
    {
        global $passtry;

        if (!$passtry)
        {
            $Passphrase = $_POST["keypass"];
            $Cancel = false;
            $passtry = true;
        }
        else
        {
            $Cancel = true;
        }
    }

    function GetStringByOID($S)
    {
        if (SBUtils\CompareContent($S, SBConstants\SB_CERT_OID_COMMON_NAME)) {
            return 'CommonName';}
        else 
        if (SBUtils\CompareContent($S, SBConstants\SB_CERT_OID_COUNTRY)) {
            return 'Country';}
        else
        if (SBUtils\CompareContent($S, SBConstants\SB_CERT_OID_LOCALITY)) {
            return 'Locality';}
        else
        if (SBUtils\CompareContent($S, SBConstants\SB_CERT_OID_STATE_OR_PROVINCE)) {
            return 'StateOrProvince';}
        else
        if (SBUtils\CompareContent($S, SBConstants\SB_CERT_OID_ORGANIZATION)) {
            return 'Organization';}
        else
        if (SBUtils\CompareContent($S, SBConstants\SB_CERT_OID_ORGANIZATION_UNIT)) {
            return 'OrganizationUnit';}
        else
        if (SBUtils\CompareContent($S, SBConstants\SB_CERT_OID_EMAIL)) {
            return 'Email';}
        else {
            return 'UnknownField';}
    }

    function WriteCertificateInfo($Storage, $eol)
    {
        $s = '';

        if ($Storage->Count > 0)
        {
            for ($i = 0; $i <= $Storage->Count - 1; $i++)
            {
                $Cert = $Storage->get_Certificates($i);
                $s = $s . " Certificate #" . ($i + 1) . ": " . $eol;

                $s = $s . "  Issuer: " . $eol;
                for ($j = 0; $j <= $Cert->IssuerRDN->Count - 1; $j++)
                {
                    $s = $s . '   ' . GetStringByOID($Cert->IssuerRDN->get_OIDs($j)) . '=' . $Cert->IssuerRDN->get_Values($j) . $eol;
                }

                $s = $s . "  Subject: " . $eol;
                for ($j = 0; $j <= $Cert->SubjectRDN->Count - 1; $j++)
                {
                    $s = $s . '   ' . GetStringByOID($Cert->SubjectRDN->get_OIDs($j)) . '=' . $Cert->SubjectRDN->get_Values($j) . $eol;
                }

                if ($Cert->PrivateKeyExists)
                {
                    $s = $s . '  Private key available';
                }
                else
                {
                    $s = $s . '  Private key is not available';
                }

                $s = $s . $eol. $eol;
            }
        }
        else
        {
            $s = $s . $eol. $eol;
        }

        return $s;
    }

    function GetPublicKeyNames($Key)
    {
        $s = '';
        if (empty($Key))
        {
            return "";
        }

        for ($i = 0; $i <= $Key->UserIDCount - 1; $i++)
        {
            if ($Key->get_UserIDs($i)->Name != '')
            {
                if ($s != '') {$s = $s . ', ';}

                $s = $s . $Key->get_UserIDs($i)->Name;
            }
        }

        return $s;
    }

    function WriteKeyringInfo($Keyring, $eol)
    {
        $s = '';

        if ($Keyring->SecretCount > 0)
        {
            $s = $s . "Secret Keys: " . $eol;

            for ($i = 0; $i <= $Keyring->SecretCount - 1; $i++)
            {
                $s = $s . "  Key #" . ($i + 1) . ": " . $eol;
                $s = $s . "   Names: " . GetPublicKeyNames($Keyring->get_SecretKeys($i)->PublicKey) . $eol;
                $s = $s . "   KeyID: " . SBPGPUtils\KeyID2Str($Keyring->get_SecretKeys($i)->KeyID(), true) . $eol;
                $s = $s . "   KeyFP: " . SBPGPUtils\KeyFP2Str($Keyring->get_SecretKeys($i)->KeyFP()) . $eol;

                if ($Keyring->get_SecretKeys($i)->SubkeyCount > 0)
                {
                    for ($j = 0; $j <= $Keyring->get_SecretKeys($i)->SubkeyCount - 1; $j++)
                    {
                        $s = $s . "   KeyID: " . SBPGPUtils\KeyID2Str($Keyring->get_SecretKeys($i)->get_Subkeys($j)->KeyID(), true) . $eol;
                        $s = $s . "   KeyFP: " . SBPGPUtils\KeyFP2Str($Keyring->get_SecretKeys($i)->get_Subkeys($j)->KeyFP()) . $eol;
                    }
                }
            }

            $s = $s . $eol;
        }

        if ($Keyring->PublicCount > 0)
        {
            $s = $s . " Public Keys: " . $eol;

            for ($i = 0; $i <= $Keyring->PublicCount - 1; $i++)
            {
                $s = $s . "  Key #" . ($i + 1) . ": \r\n";
                $s = $s . "   Names: " . GetPublicKeyNames($Keyring->get_PublicKeys($i)) . $eol;
                $s = $s . '   KeyID: ' . SBPGPUtils\KeyID2Str($Keyring->get_PublicKeys($i)->KeyID(), true) . $eol;
                $s = $s . '   KeyFP: ' . SBPGPUtils\KeyFP2Str($Keyring->get_PublicKeys($i)->KeyFP()) . $eol;

                if ($Keyring->get_PublicKeys($i)->SubkeyCount > 0)
                {
                    for ($j = 0; $j <= $Keyring->get_PublicKeys($i)->SubkeyCount - 1; $j++)
                    {
                        $s = $s . "   KeyID: " . SBPGPUtils\KeyID2Str($Keyring->get_PublicKeys($i)->get_Subkeys($j)->KeyID(), true) . $eol;
                        $s = $s . "   KeyFP: " . SBPGPUtils\KeyFP2Str($Keyring->get_PublicKeys($i)->get_Subkeys($j)->KeyFP()) . $eol;
                    }
                }
            }
        }

        return $s;
    }

    function GetAlgorithmBitsInKey()
    {
        global $encalg;

        switch ($encalg)
        {
            case 0 : return 56; break;
            case 1 : return 168; break;
            case 2 : return 128; break;
            case 3 : return 40; break;
            case 4 : return 128; break;
            case 5 : return 128; break;
            case 6 : return 192; break;
            case 7 : return 256; break;
            default : return 168;
        }
    }

    function GetAlgorithm()
    {
        global $encalg;

        switch ($encalg)
        {
            case 0 : return SBConstants\SB_ALGORITHM_CNT_DES; break;
            case 1 : return SBConstants\SB_ALGORITHM_CNT_3DES; break;
            case 2 : return SBConstants\SB_ALGORITHM_CNT_RC2; break;
            case 3 :
            case 4 : return SBConstants\SB_ALGORITHM_CNT_RC4; break;
            case 5 : return SBConstants\SB_ALGORITHM_CNT_AES128; break;
            case 6 : return SBConstants\SB_ALGORITHM_CNT_AES192; break;
            case 7 : return SBConstants\SB_ALGORITHM_CNT_AES256; break;
            default : return SBConstants\SB_ALGORITHM_CNT_3DES;
        }
    }

    function GetAlgorithmName()
    {
        return SBConstants\GetAlgorithmNameByAlgorithm(GetAlgorithm());
    }

    function GetSignAlgorithm()
    {
        global $hash;

        switch ($hash)
        {
            case 0 : return 'MD5'; break;
            case 1 : return 'SHA1'; break;
            default : return 'SHA1';
        }
    }

    function ShowForm()
    {
        global $action;
        global $filename;
        global $certstorage;
        global $keyring;
        global $inputtemp;
        global $certtemp;
        global $keytemp;
        global $certpass;
        global $keypass;
        global $encalg;
        global $hash;

        echo '<html>';
        echo '<head>';
        echo '  <title>EldoS SecureMail demo</title>';
        echo '  <style type="text/css">';
        echo '  .textheader {';
        echo '    font-family: Arial;';
        echo '    font-size: 16;';
        echo '    font-weight: bold;';
        echo '  }';
        echo '  .textnormal {';
        echo '    font-family: Arial;';
        echo '    font-size: 12;';
        echo '  }';
        echo '  </style>';
        echo '</head>';
        echo '<body>';
        echo '  <div align="center">';
        echo '  <table border="0" cellspacing="0" cellpadding="0" width="600" height="100%">';
        echo '    <tr height="*"></tr>';
        echo '    <tr height="400">';
        echo '      <td width="600" valign="top">';
        echo '        <table border="0" cellspacing="0" cellpadding="10" width="100%" height="100%" style="border: 1px solid #bbbbbb;" bgcolor="#f6f6f6">';
        echo '          <tr height="50">';
        echo '            <td width="100%" valign="center" bgcolor="#e6e6e6">';
        echo '              <div align="center" class="textheader">EldoS SecureBlackbox SecureMail demo</div>';
        echo '            </td>';
        echo '          </tr>';
        echo '          <tr height="70">';
        echo '            <td width="100%" height="*" align="center" valign="center" class="textnormal">';
        echo '              <div align="center"> This sample illustrates the use of SecureBlackbox MIME components. </div>';
        echo '            </td>';
        echo '          </tr>';
        echo '          <tr height="*">';
        echo '            <td width="100%" height="*">';
        echo '              <form action="SecureMail.php" method="post" enctype="multipart/form-data">';
        echo '                <table border="0" cellspacing="0" cellpadding="0" width="100%" height="100%" class="textnormal">';
        echo '                  <tr height="30" valign="bottom">';

        $info = "";
        switch ($action)
        {
            case ACTION_SMIME_SIGN :
            case ACTION_PGPMIME_SIGN : $info = "Ready to start signing. Please check that all signing options are correct."; break;
            case ACTION_SMIME_VERIFY :
            case ACTION_PGPMIME_VERIFY : $info = "Ready to start verifying. Please check that all options are correct."; break;
            case ACTION_SMIME_ENCRYPT :
            case ACTION_PGPMIME_ENCRYPT : $info = "Ready to start encryption. Please check all the parameters to be valid."; break;
            case ACTION_SMIME_DECRYPT :
            case ACTION_PGPMIME_DECRYPT : $info = "Ready to start decryption. Please check that all decryption options are correct."; break;
        }
        echo '                    <td colspan="3" align="center"> <span class="mtx4">' . $info . '</span> </td>';
        echo '                  </tr>';
        echo '                  <tr height="50">';
        echo '                    <td colspan="3" align="center">';
        echo '                      <textarea readonly name="info" cols=70 rows=20>';

        $log = '';

        switch ($action)
        {
            case ACTION_SMIME_SIGN :
            case ACTION_PGPMIME_SIGN :
                $log = $log . "File to sign: " . $filename . " \r\n \r\n";

                if ($action == ACTION_SMIME_SIGN)
                {
                    $log = $log . "Certificates: \r\n";
                    $log = $log . WriteCertificateInfo($certstorage, " \r\n");
                    $log = $log . "Algorithm: " . GetAlgorithmName();
                }
                else
                {
                    $log = $log . "Keys: \r\n ";
                    $log = $log . WriteKeyringInfo($keyring, " \r\n");
                }

                break;
            case ACTION_SMIME_VERIFY :
            case ACTION_PGPMIME_VERIFY :
                $log = $log . "File to verify: " . $filename . " \r\n \r\n";

                if ($action == ACTION_SMIME_VERIFY)
                {
                    $log = $log . "Certificates: \r\n";
                    $log = $log . WriteCertificateInfo($certstorage, " \r\n");
                }
                else
                {
                    $log = $log . "Keys: \r\n ";
                    $log = $log . WriteKeyringInfo($keyring, " \r\n");
                }

                break;
            case ACTION_SMIME_ENCRYPT :
            case ACTION_PGPMIME_ENCRYPT :
                $log = $log . "File to encrypt: " . $filename . " \r\n \r\n";

                if ($action == ACTION_SMIME_ENCRYPT)
                {
                    $log = $log . "Certificates: \r\n";
                    $log = $log . WriteCertificateInfo($certstorage, " \r\n");
                    $log = $log . "Algorithm: " . GetAlgorithmName();
                }
                else
                {
                    $log = $log . "Keys: \r\n ";
                    $log = $log . WriteKeyringInfo($keyring, " \r\n");
                }

                break;
            case ACTION_SMIME_DECRYPT :
            case ACTION_PGPMIME_DECRYPT :
                $log = $log . "File to decrypt: " . $filename . " \r\n \r\n";

                if ($action == ACTION_SMIME_DECRYPT)
                {
                    $log = $log . "Certificates: \r\n";
                    $log = $log . WriteCertificateInfo($certstorage, " \r\n");
                }
                else
                {
                    $log = $log . "Keys: \r\n ";
                    $log = $log . WriteKeyringInfo($keyring, " \r\n");
                }

                break;
        }

        echo $log;
        echo '                      </textarea>';
        echo '                    </td>';
        echo '                  </tr>';
        echo '                  <tr height="0" valign="bottom">';
        echo '                    <td colspan="3" align="left"> <input type="hidden" name="action" value="' . $action . '" size="30" /> </td>';
        echo '                  </tr>';
        echo '                  <tr height="0" valign="bottom">';
        echo '                    <td colspan="3" align="left"> <input type="hidden" name="inputfile" value="' . $inputtemp . '" size="30" /> </td>';
        echo '                  </tr>';
        echo '                  <tr height="0" valign="bottom">';
        echo '                    <td colspan="3" align="left"> <input type="hidden" name="filename" value="' . $filename . '" size="30" /> </td>';
        echo '                  </tr>';
        echo '                  <tr height="0" valign="bottom">';
        echo '                    <td colspan="3" align="left"> <input type="hidden" name="encalg" value="' . $encalg . '" size="30" /> </td>';
        echo '                  </tr>';
        echo '                  <tr height="0" valign="bottom">';
        echo '                    <td colspan="3" align="left"> <input type="hidden" name="hash" value="' . $hash . '" size="30" /> </td>';
        echo '                  </tr>';
        echo '                  <tr height="0" valign="bottom">';
        echo '                    <td colspan="3" align="left"> <input type="hidden" name="certfile" value="' . $certtemp . '" size="30" /> </td>';
        echo '                  </tr>';
        echo '                  <tr height="0" valign="bottom">';
        echo '                    <td colspan="3" align="left"> <input type="hidden" name="certpass" value="' . $certpass . '" size="30" /> </td>';
        echo '                  </tr>';
        echo '                  <tr height="0" valign="bottom">';
        echo '                    <td colspan="3" align="left"> <input type="hidden" name="keyfile" value="' . $keytemp . '" size="30" /> </td>';
        echo '                  </tr>';
        echo '                  <tr height="0" valign="bottom">';
        echo '                    <td colspan="3" align="left"> <input type="hidden" name="keypass" value="' . $keypass . '" size="30" /> </td>';
        echo '                  </tr>';
        echo '                  <tr height="40" valign="bottom">';

        switch ($action)
        {
            case ACTION_SMIME_SIGN :
            case ACTION_PGPMIME_SIGN :
                echo '                    <td colspan=3 align="center"> <input type="submit" name="sign" value="Sign"/> </td>';
                break;
            case ACTION_SMIME_VERIFY :
            case ACTION_PGPMIME_VERIFY :
                echo '                    <td colspan=3 align="center"> <input type="submit" name="verify" value="Verify"/> </td>';
                break;
            case ACTION_SMIME_ENCRYPT :
            case ACTION_PGPMIME_ENCRYPT :
                echo '                    <td colspan=3 align="center"> <input type="submit" name="encrypt" value="Encrypt"/> </td>';
                break;
            case ACTION_SMIME_DECRYPT :
            case ACTION_PGPMIME_DECRYPT :
                echo '                    <td colspan=3 align="center"> <input type="submit" name="decrypt" value="Decrypt"/> </td>';
                break;
        }

        echo '                  </tr>';
        echo '                  <tr height="30" valign="bottom">';
        echo '                    <td colspan="3" align="center"> Please inspect the source code of this script for more details. </td>';
        echo '                  </tr>';
        echo '                </table>';
        echo '              </form>';
        echo '            </td>';
        echo '          </tr>';
        echo '          <tr height="20">';
        echo '            <td width="100%" valign="center" bgcolor="#e6e6e6">';
        echo '              <div align="center" class="textnormal">Copyright &copy; EldoS Corporation <a href="http://www.eldos.com/">www.eldos.com</a></div>';
        echo '            </td>';
        echo '          </tr>';
        echo '        </table>';
        echo '      </td>';
        echo '    </tr>';
        echo '    <tr height="*"></tr>';
        echo '  </table>';
        echo '  </div>';
        echo '</body>';
        echo '</html>';
    }

    if (isset($_POST["encrypt"])) 
    {
        $action = $_POST["action"];
        $inputfile = $_POST["inputfile"];
        $filename = $_POST["filename"];

        $in = new TMemoryStream;
        $in->LoadFromFile($inputfile);

        $err = '';
        $Msg = new TElMessage("");
        try
        {
            $options = (TElMessageParsingOption::mpoStoreStream | TElMessageParsingOption::mpoLoadData | TElMessageParsingOption::mpoCalcDataSize);
            $Res = $Msg->ParseMessage($in, '', '', $options, False, False, True);
        }
        catch(SBException $e)
        {
            $err = $e->getMessage();
            $Res = SBMIME\EL_ERROR;
        }

        if (($Res != SBMIME\EL_OK) and ($Res != SBMIME\EL_WARNING))
        {
            if ($err != '')
            {
                $err = 'Message: "' . $err . '"';
            }
            else
            if (($Res == SBMIME\EL_HANDLERR_ERROR) and !empty($Msg->MainPart->MessagePartHandler))
            {
                $err = 'Message: "' + $Msg->MainPart->MessagePartHandler->ErrorText . '"';
            }

            print 'Error parsing mime message "' . $filename . '". <br/> ElMime error code: ' . $Res . ' <br/> ' . $err;
            return;
        }

        $SMime = new TElMessagePartHandlerSMime(NULL);
        $PGPMime = new TElMessagePartHandlerPGPMime(NULL);
        if ($action == ACTION_SMIME_ENCRYPT)
        {
            $encalg = $_POST['encalg'];
            $certfile = $_POST["certfile"];
            $certpass = $_POST["certpass"];
            $cert = new TElX509Certificate(NULL);
            $r = $cert->LoadFromFileAuto($certfile, $certpass);
            if ($r != 0)
            {
                print 'Failed to load certificate, error ' . $r;
                return;
            }
            $certstorage->Add($cert, true);

            $SMime->set_EncoderCryptCertStorage($certstorage);
            $Msg->get_MainPart()->set_MessagePartHandler($SMime);

            $SMime->set_EncoderCrypted(True);
            $SMime->set_EncoderCryptBitsInKey(GetAlgorithmBitsInKey());
            $SMime->set_EncoderCryptAlgorithm(GetAlgorithm());

            unlink($certfile);
        }
        else
        {
            $keyfile = $_POST["keyfile"];
            $keyring->Load($keyfile, '', true);

            $Msg->get_MainPart()->set_MessagePartHandler($PGPMime);

            $PGPMime->set_EncryptingKeys($keyring);
            $PGPMime->set_Encrypt(True);

            unlink($keyfile);
        }

        $err = '';
        $out = new TMemoryStream;
        try
        {
            $Res = $Msg->AssembleMessage($out,
                   // Charset of message:
                   'utf-8',
                   // HeaderEncoding
                   TElHeaderEncoding::heBase64, //  variants:  he8bit  | heQuotedPrintable  | heBase64
                   // BodyEncoding
                   'base64', //  variants:   '8bit' | 'quoted-printable' |  'base64'
                   // AttachEncoding
                   'base64',  //  variants:   '8bit' | 'quoted-printable' |  'base64'
                   false);
        }
        catch(SBException $e)
        {
            $err = $e->getMessage();
            $Res = SBMIME\EL_ERROR;
        }

        if (($Res == SBMIME\EL_OK) or ($Res == SBMIME\EL_WARNING))
        {
            $yourfile = basename($filename) . ".tmp";
            $tempname = tempnam(sys_get_temp_dir(), $yourfile);

            $out->SaveToFile($tempname);

            if (ob_get_level()) 
            {
                ob_end_clean();
            }

            header('Content-Description: File Transfer');
            header('Content-Type: application/octet-stream');
            header("Content-Disposition: attachment; filename=$filename");
            header('Content-Transfer-Encoding: binary');
            header('Expires: 0');
            header('Cache-Control: must-revalidate');
            header('Pragma: public');
            header('Content-Length: ' . filesize($tempname));
            readfile($tempname);

            unlink($tempname);
            unlink($inputfile);

            //print 'Message encrypted and assembled OK';
        }
        else
        {
            if ($err != '')
            {
                $err = 'Message: "' . $err . '"';
            }
            else
            if ($Res == SBMIME\EL_HANDLERR_ERROR)
            {
                if ($action == ACTION_SMIME_ENCRYPT)
                {
                    $err = 'Message: "' . $SMime->ErrorText . '"';
                }
                else
                {
                    $err = 'Message: "' . $PGPMime->ErrorText . '"';
                }
            }

            print 'Failed to assemble a message. <br/> ElMime error code: ' . $Res . '<br/>' . $err;
        }

        $SMime->detachHandle();
        $PGPMime->detachHandle();

        return;
    }

    if (isset($_POST["decrypt"])) 
    {
        $action = $_POST["action"];
        $inputfile = $_POST["inputfile"];
        $filename = $_POST["filename"];

        $in = new TMemoryStream;
        $in->LoadFromFile($inputfile);

        $err = '';
        $Msg = new TElMessage("");
        try
        {
            $options = (TElMessageParsingOption::mpoStoreStream | TElMessageParsingOption::mpoLoadData | TElMessageParsingOption::mpoCalcDataSize);
            $Res = $Msg->ParseMessage($in, '', '', $options, False, False, False);
        }
        catch(SBException $e)
        {
            $err = $e->getMessage();
            $Res = SBMIME\EL_ERROR;
        }

        if (($Res == SBMIME\EL_OK) or ($Res == SBMIME\EL_WARNING))
        {
            if (empty($Msg->get_MainPart()) or empty($Msg->get_MainPart()->get_MessagePartHandler()) or
                $Msg->get_MainPart()->IsActivatedMessagePartHandler)
            {
                print 'Mesage not encoded. No action done.';
                return;
            }

            if ($Msg->get_MainPart()->get_MessagePartHandler()->IsError)
            {
                $err = $Msg->get_MainPart()->get_MessagePartHandler()->ErrorText;
                $Res = SBMIME\EL_ERROR;
            }
            else
            {
                if (($Msg->get_MainPart()->get_MessagePartHandler()->ClassName_Inst() == 'TElMessagePartHandlerSMime') and
                   ($action == ACTION_SMIME_DECRYPT))
                {
                    $certfile = $_POST["certfile"];
                    $certpass = $_POST["certpass"];
                    $cert = new TElX509Certificate(NULL);
                    $r = $cert->LoadFromFileAuto($certfile, $certpass);
                    if ($r != 0)
                    {
                        print 'Failed to load certificate, error ' . $r;
                        return;
                    }
                    $certstorage->Add($cert, true);

                    $Msg->get_MainPart()->get_MessagePartHandler()->CastTo()->set_CertificatesStorage($certstorage);

                    try
                    {
                        $Res = $Msg->get_MainPart()->get_MessagePartHandler()->CastTo()->Decode(True);
                    }
                    catch(SBException $e)
                    {
                        $err = $e->getMessage();
                        $Res = SBMIME\EL_ERROR;
                    }

                    unlink($certfile);
                }
                else
                if (($Msg->get_MainPart()->get_MessagePartHandler()->ClassName_Inst() == 'TElMessagePartHandlerPGPMime') and
                   ($action == ACTION_PGPMIME_DECRYPT))
                {
                    $keyfile = $_POST["keyfile"];
                    $tempkey = new TElPGPKeyring(NULL);
                    $tempkey->Load($keyfile, '', true);
                    $tempkey->ExportTo($keyring);

                    $Msg->get_MainPart()->get_MessagePartHandler()->CastTo()->set_DecryptingKeys($keyring);
                    $Msg->get_MainPart()->get_MessagePartHandler()->CastTo()->OnKeyPassphrase = "PGPMIMEKeyPassphrase";

                    try
                    {
                        $Res = $Msg->get_MainPart()->get_MessagePartHandler()->CastTo()->Decode(True);
                    }
                    catch(SBException $e)
                    {
                        $err = $e->getMessage();
                        $Res = SBMIME\EL_ERROR;
                    }

                    unlink($keyfile);
                }
                else
                {
                    $err = 'Unknown message handler.';
                    $Res = SBMIME\EL_ERROR;
                }
            }
        }

        if (($Res != SBMIME\EL_OK) and ($Res != SBMIME\EL_WARNING))
        {
            if ($err != '')
            {
                $err = 'Message: "' . $err . '"';
            }
            else
            if (($Res == SBMIME\EL_HANDLERR_ERROR) and !empty($Msg->get_MainPart()->get_MessagePartHandler()))
            {
                $err = 'Message: "' . $Msg->get_MainPart()->get_MessagePartHandler()->ErrorText . '"';
            }

            print 'Error parsing mime message "' . $filename . '". <br/> ElMime error code: ' . $Res . ' <br/> ' . $err;
            return;
        }

        // WARNING!
        // When you replace the main part of a message, all top level message headers are lost!
        // If you need to reassemble the message after decryption and top level headers are
        // required, then you have to copy the message header before replacing the main part,
        // and mix the copied header with the header of the decoded part.
        $MainPart = $Msg->get_MainPart()->get_MessagePartHandler()->DecodedPart;
        $Header = new TElMessageHeader();

        $Header->Assign($MainPart->get_Header());             // store header from the decoded part
        // merge headers
        // merge parsed mail addresses
        while ($Msg->get_MainPart()->get_Header()->MailAddressListCount > 0)
        {
            $MailList = $Msg->get_MainPart()->get_Header()->GetMailAddressList(0);
            $FieldName = $MailList->FieldName;
            // although internal parts usually do not contain mail addresses
            // it's better to check this in order not to have two From fields
            $Add = (($Header->GetMailAddressList($FieldName, 0) == NULL) and !$Header->FieldExists($FieldName));
            $p = new TSBPointer();
            $p->fromObject($MailList);
            $Msg->get_MainPart()->get_Header()->get_AddressList()->Remove($p);
            if ($Add)
            {
                $Header->AddMailAddressList($MailList->CastTo());
            }
        }
        // merge other fields
        while ($Msg->get_MainPart()->get_Header()->FieldsCount > 0)
        {
            $Field = $Msg->get_MainPart()->get_Header()->GetField(0);
            $FieldName = $Field->Name;
            $Add = (!(stristr($FieldName, "Content-") == False) and !$Header->FieldExists($FieldName));

            do
            {
                $p = new TSBPointer();
                $p->fromObject($Field);
                $Msg->get_MainPart()->get_Header()->HeaderFields->Remove($p);
                if ($Add)
                {
                    $Header->HeaderFields->Add($Field);
                }

                $Field = $Msg->get_MainPart()->get_Header()->GetField($FieldName, 0);
            }
            while ($Field != NULL);
        }
        //end merge

        $Msg->get_MainPart()->get_MessagePartHandler()->set_DecodedPart(NULL);
        $Msg->SetMainPart($MainPart, False);
        $MainPart->get_Header()->Assign($Header);


        $err = '';
        $out = new TMemoryStream;
        try
        {
            $Res = $Msg->AssembleMessage($out,
                   // Charset of message:
                   'utf-8',
                   // HeaderEncoding
                   TElHeaderEncoding::heBase64, //  variants:  he8bit  | heQuotedPrintable  | heBase64
                   // BodyEncoding
                   'base64', //  variants:   '8bit' | 'quoted-printable' |  'base64'
                   // AttachEncoding
                   'base64',  //  variants:   '8bit' | 'quoted-printable' |  'base64'
                   False     // DO NOT USE TRUE because the decrypted part DOES NOT SAVE ITS SOURCE
                   );
        }
        catch(SBException $e)
        {
            $err = $e->getMessage();
            $Res = SBMIME\EL_ERROR;
        }

        if (($Res == SBMIME\EL_OK) or ($Res == SBMIME\EL_WARNING))
        {
            $yourfile = basename($filename) . ".tmp";
            $tempname = tempnam(sys_get_temp_dir(), $yourfile);

            $out->SaveToFile($tempname);

            if (ob_get_level()) 
            {
                ob_end_clean();
            }

            header('Content-Description: File Transfer');
            header('Content-Type: application/octet-stream');
            header("Content-Disposition: attachment; filename=$filename");
            header('Content-Transfer-Encoding: binary');
            header('Expires: 0');
            header('Cache-Control: must-revalidate');
            header('Pragma: public');
            header('Content-Length: ' . filesize($tempname));
            readfile($tempname);

            unlink($tempname);
            unlink($inputfile);

            return;
            //print 'Message decrypted and assembled OK';
        }
        else
        {
            if ($err != '')
            {
                $err = 'Message: "' . $err . '"';
            }
            else
            if (($Res == SBMIME\EL_HANDLERR_ERROR) and !empty($Msg->get_MainPart()->get_MessagePartHandler()))
            {
                $err = 'Message: "' . $Msg->get_MainPart()->get_MessagePartHandler()->ErrorText . '"';
            }

            print 'Failed to assemble a message. <br/> ElMime error code: ' . $Res . ' <br/> ' . $err;
            return;
        }
    }

    if (isset($_POST["sign"])) 
    {
        $action = $_POST["action"];
        $inputfile = $_POST["inputfile"];
        $filename = $_POST["filename"];

        $in = new TMemoryStream;
        $in->LoadFromFile($inputfile);

        $err = '';
        $Msg = new TElMessage("");
        try
        {
            $options = (TElMessageParsingOption::mpoStoreStream | TElMessageParsingOption::mpoLoadData | TElMessageParsingOption::mpoCalcDataSize);
            $Res = $Msg->ParseMessage($in, '', '', $options, False, False, True);
        }
        catch(SBException $e)
        {
            $err = $e->getMessage();
            $Res = SBMIME\EL_ERROR;
        }

        if (($Res != SBMIME\EL_OK) and ($Res != SBMIME\EL_WARNING))
        {
            if ($err != '')
            {
                $err = 'Message: "' . $err . '"';
            }
            else
            if (($Res == SBMIME\EL_HANDLERR_ERROR) and !empty($Msg->MainPart->MessagePartHandler))
            {
                $err = 'Message: "' + $Msg->MainPart->MessagePartHandler->ErrorText . '"';
            }

            print 'Error parsing mime message "' . $filename . '". <br/> ElMime error code: ' . $Res . ' <br/> ' . $err;
            return;
        }

        try
        {
        $SMime = new TElMessagePartHandlerSMime(NULL);
        $PGPMime = new TElMessagePartHandlerPGPMime(NULL);
        if ($action == ACTION_SMIME_SIGN)
        {
            $hash = $_POST['hash'];
            $certfile = $_POST["certfile"];
            $certpass = $_POST["certpass"];
            $cert = new TElX509Certificate(NULL);
            $r = $cert->LoadFromFileAuto($certfile, $certpass);
            if ($r != 0)
            {
                print 'Failed to load certificate, error ' . $r;
                return;
            }
            $certstorage->Add($cert, true);

            $SMime->set_EncoderSignCertStorage($certstorage);
            $Msg->get_MainPart()->set_MessagePartHandler($SMime);

            $SMime->set_EncoderSigned(True);
            $SMime->set_EncoderSignOnlyClearFormat(True);
            $SMime->set_EncoderMicalg(GetSignAlgorithm());

            unlink($certfile);
        }
        else
        {
            $keyfile = $_POST["keyfile"];
            $keyring->Load($keyfile, '', true);

            $Msg->get_MainPart()->set_MessagePartHandler($PGPMime);

            $PGPMime->set_SigningKeys($keyring);
            $PGPMime->set_OnKeyPassphrase("PGPMIMEKeyPassphrase");
            $PGPMime->set_Sign(True);

            unlink($keyfile);
        }

        $err = '';
        $out = new TMemoryStream;
            $Res = $Msg->AssembleMessage($out,
                   // Charset of message:
                   'utf-8',
                   // HeaderEncoding
                   TElHeaderEncoding::heBase64, //  variants:  he8bit  | heQuotedPrintable  | heBase64
                   // BodyEncoding
                   'base64', //  variants:   '8bit' | 'quoted-printable' |  'base64'
                   // AttachEncoding
                   'base64',  //  variants:   '8bit' | 'quoted-printable' |  'base64'
                   false);
        }
        catch(SBException $e)
        {
            $err = $e->getMessage();
            $Res = SBMIME\EL_ERROR;
        }

        if (($Res == SBMIME\EL_OK) or ($Res == SBMIME\EL_WARNING))
        {
            $yourfile = basename($filename) . ".tmp";
            $tempname = tempnam(sys_get_temp_dir(), $yourfile);

            $out->SaveToFile($tempname);

            if (ob_get_level()) 
            {
                ob_end_clean();
            }

            header('Content-Description: File Transfer');
            header('Content-Type: application/octet-stream');
            header("Content-Disposition: attachment; filename=$filename");
            header('Content-Transfer-Encoding: binary');
            header('Expires: 0');
            header('Cache-Control: must-revalidate');
            header('Pragma: public');
            header('Content-Length: ' . filesize($tempname));
            readfile($tempname);

            unlink($tempname);
            unlink($inputfile);

            //print 'Message signed and assembled OK';
        }
        else
        {
            if ($err != '')
            {
                $err = 'Message: "' . $err . '"';
            }
            else
            if ($Res == SBMIME\EL_HANDLERR_ERROR)
            {
                if ($action == ACTION_SMIME_SIGN)
                {
                    $err = 'Message: "' . $SMime->ErrorText . '"';
                }
                else
                {
                    $err = 'Message: "' . $PGPMime->ErrorText . '"';
                }
            }

            print 'Failed to assemble a message. <br/> ElMime error code: ' . $Res . '<br/>' . $err;
        }

        $SMime->detachHandle();
        $PGPMime->detachHandle();

        return;
    }

    if (isset($_POST["verify"])) 
    {
        $action = $_POST["action"];
        $inputfile = $_POST["inputfile"];
        $filename = $_POST["filename"];

        $in = new TMemoryStream;
        $in->LoadFromFile($inputfile);

        $log = '';
        $Msg = new TElMessage("");
        try
        {
            $options = (TElMessageParsingOption::mpoStoreStream | TElMessageParsingOption::mpoLoadData | TElMessageParsingOption::mpoCalcDataSize);
            $Res = $Msg->ParseMessage($in, '', '', $options, False, False, False);
        }
        catch(SBException $e)
        {
            $log = $e->getMessage();
            $Res = SBMIME\EL_ERROR;
        }

        if (($Res == SBMIME\EL_OK) or ($Res == SBMIME\EL_WARNING))
        {
            if (empty($Msg->get_MainPart()) or empty($Msg->get_MainPart()->get_MessagePartHandler()) or
                $Msg->get_MainPart()->IsActivatedMessagePartHandler)
            {
                print 'Mesage not encoded. No action done.';
                return;
            }

            if ($Msg->get_MainPart()->get_MessagePartHandler()->IsError)
            {
                $log = $Msg->get_MainPart()->get_MessagePartHandler()->ErrorText;
                $Res = SBMIME\EL_ERROR;
            }
            else
            {
                if (($Msg->get_MainPart()->get_MessagePartHandler()->ClassName_Inst() == 'TElMessagePartHandlerSMime') and
                   ($action == ACTION_SMIME_VERIFY))
                {
                    $certfile = $_POST["certfile"];
                    $certpass = $_POST["certpass"];
                    $cert = new TElX509Certificate(NULL);
                    $r = $cert->LoadFromFileAuto($certfile, $certpass);
                    if ($r != 0)
                    {
                        print 'Failed to load certificate, error ' . $r;
                        return;
                    }
                    $certstorage->Add($cert, true);

                    $Msg->get_MainPart()->get_MessagePartHandler()->CastTo()->set_CertificatesStorage($certstorage);

                    try
                    {
                        $Res = $Msg->get_MainPart()->get_MessagePartHandler()->Decode(True);
                    }
                    catch(SBException $e)
                    {
                        $log = $e->getMessage();
                        $Res = SBMIME\EL_ERROR;
                    }

                    if ($Msg->get_MainPart()->get_MessagePartHandler()->CastTo()->get_Errors() !=0)
                    {
                        if ($log != '') { $log = $log . ' <br/> ';}

                        if ($Res == SBMIME\EL_WARNING)
                        {
                            $log = $log . 'Warnings: ';
                        }
                        else
                        {
                            $log = $log . 'Errors: ';
                        }

                        if (($Msg->get_MainPart()->get_MessagePartHandler()->CastTo()->get_Errors() & TElSMimeError::smeUnknown) > 0) {
                            $log = $log . 'smeUnknown, ';}

                        if (($Msg->get_MainPart()->get_MessagePartHandler()->CastTo()->get_Errors() & TElSMimeError::smeSignaturePartNotFound) > 0) {
                            $log = $log . 'smeSignaturePartNotFound, ';}

                        if (($Msg->get_MainPart()->get_MessagePartHandler()->CastTo()->get_Errors() & TElSMimeError::smeBodyPartNotFound) > 0) {
                            $log = $log . 'smeBodyPartNotFound, ';}

                        if (($Msg->get_MainPart()->get_MessagePartHandler()->CastTo()->get_Errors() & TElSMimeError::smeInvalidSignature) > 0) {
                            $log = $log . 'smeInvalidSignature, ';}

                        if (($Msg->get_MainPart()->get_MessagePartHandler()->CastTo()->get_Errors() & TElSMimeError::smeSigningCertificateMismatch) > 0) {
                            $log = $log . 'smeSigningCertificateMismatch, ';}

                        if (($Msg->get_MainPart()->get_MessagePartHandler()->CastTo()->get_Errors() & TElSMimeError::smeEncryptingCertificateMismatch) > 0) {
                            $log = $log . 'smeEncryptingCertificateMismatch, ';}

                        if (($Msg->get_MainPart()->get_MessagePartHandler()->CastTo()->get_Errors() & TElSMimeError::smeNoData) > 0) {
                            $log = $log . 'smeNoData, ';}

                        $log = substr($log, 0, -2);
                    }

                    unlink($certfile);
                }
                else
                if (($Msg->get_MainPart()->get_MessagePartHandler()->ClassName_Inst() == 'TElMessagePartHandlerPGPMime') and
                   ($action == ACTION_PGPMIME_VERIFY))
                {
                    $keyfile = $_POST["keyfile"];
                    $keyring->Load($keyfile, '', true);

                    $Msg->get_MainPart()->get_MessagePartHandler()->CastTo()->set_VerifyingKeys($keyring);

                    try
                    {
                        $Res = $Msg->get_MainPart()->get_MessagePartHandler()->Decode(True);
                    }
                    catch(SBException $e)
                    {
                        $log = $e->getMessage();
                        $Res = SBMIME\EL_ERROR;
                    }

                    unlink($keyfile);
                }
                else
                {
                    $err = 'Unknown message handler.';
                    $Res = SBMIME\EL_ERROR;
                }
            }
        }

        if (($Res != SBMIME\EL_OK) and ($Res != SBMIME\EL_WARNING))
        {
            if ($log != '')
            {
                $log = 'Message: "' . $log . '"';
            }
            else
            if (($Res == SBMIME\EL_HANDLERR_ERROR) and !empty($Msg->get_MainPart()->get_MessagePartHandler()))
            {
                $log = 'Message: "' . $Msg->get_MainPart()->get_MessagePartHandler()->ErrorText . '"';
            }

            print 'Error parsing mime message "' . $filename . '". <br/> ElMime error code: ' . $Res . ' <br/> ' . $log;
            return;
        }
        else
        {
            if ($Res == SBMIME\EL_WARNING)
            {
                $log = 'Message is verified with warnings: <br/> ' . $log;
            }
            else
            {
                $log = 'Message verified OK';
            }

            if (!empty($Msg->get_MainPart()->get_MessagePartHandler()) and
               ($Msg->get_MainPart()->get_MessagePartHandler()->ClassName_Inst() == 'TElMessagePartHandlerSMime'))
            {
                $log = $log .' <br/> <br/> Signed with: <br/>';
                $log = $log . WriteCertificateInfo($Msg->get_MainPart()->get_MessagePartHandler()->CastTo()->get_DecoderSignCertStorage(), " <br/>");
            }
      
            if (!empty($Msg->get_MainPart()->get_MessagePartHandler()) and
               ($Msg->get_MainPart()->get_MessagePartHandler()->ClassName_Inst() == 'TElMessagePartHandlerPGPMime'))
            {
                $log = $log .' <br/> <br/> Signature verified with: <br/>';
                $log = $log . WriteKeyringInfo($Msg->get_MainPart()->get_MessagePartHandler()->CastTo()->get_VerifyingKeys(), " <br/>");
            }

            print $log;
            return;
        }
    }

    if (isset($_POST["next"])) 
    {
        if (!extension_loaded("sbb") && !function_exists('SBUtils\SetLicenseKey')) 
        {
            print "SecureBlackbox extension is not available, please check that you've set it up correctly";
            die;
        }

        $action = $_POST['actions'];
        if (isset($_POST['hash'])) {$hash = $_POST['hash'];}
        if (isset($_POST['encalg'])) {$encalg = $_POST['encalg'];}
        if (isset($_FILES['certfile']))
        {
            $certfile = $_FILES["certfile"]["tmp_name"];
            $certname = $_FILES["certfile"]["name"];
        }
        if (isset($_POST['certpass'])) {$certpass = $_POST['certpass'];}
        if (isset($_FILES['seckey']))
        {
            $keyfile = $_FILES["seckey"]["tmp_name"];
            $keyname = $_FILES["seckey"]["tmp_name"];
        }
        if (isset($_FILES['pubkey']))
        {
            $keyfile = $_FILES["pubkey"]["tmp_name"];
            $keyname = $_FILES["pubkey"]["tmp_name"];
        }
        if (isset($_FILES['seckey1']))
        {
            $keyfile = $_FILES["seckey1"]["tmp_name"];
            $keyname = $_FILES["seckey1"]["tmp_name"];
        }
        if (isset($_FILES['pubkey1']))
        {
            $keyfile = $_FILES["pubkey1"]["tmp_name"];
            $keyname = $_FILES["pubkey1"]["tmp_name"];
        }
        if (isset($_POST['keypass'])) {$keypass = $_POST['keypass'];}
        $inputfile = $_FILES["inputfile"]["tmp_name"];
        $filename = $_FILES["inputfile"]["name"];

        if (strlen($inputfile) > 0)
        {
            if (($action == ACTION_SMIME_SIGN) or ($action == ACTION_SMIME_VERIFY) or
                ($action == ACTION_SMIME_ENCRYPT) or ($action == ACTION_SMIME_DECRYPT))
            {
                if (strlen($certfile) == 0)
                {
                    print "Certificate file is not provided";
                    return;
                }

                $cert = new TElX509Certificate(NULL);
                $r = $cert->LoadFromFileAuto($certfile, $certpass);
                if ($r != 0)
                {
                    print 'Failed to load certificate, error ' . $r;
                    return;
                }

                $certstorage->Add($cert, true);

                $certtemp = tempnam(sys_get_temp_dir(), $certname);
                if (!copy($certfile, $certtemp)) 
                {
                    print "Can not copy $certfile...\n";
                    die;
                }
            }

            if (($action == ACTION_PGPMIME_SIGN) or ($action == ACTION_PGPMIME_VERIFY) or
                ($action == ACTION_PGPMIME_ENCRYPT) or ($action == ACTION_PGPMIME_DECRYPT))
            {
                if (strlen($keyfile) == 0)
                {
                    print "PGP key file is not provided";
                    return;
                }

                $keyring->Load($keyfile, '', true);

                $keytemp = tempnam(sys_get_temp_dir(), $keyname);
                if (!copy($keyfile, $keytemp)) 
                {
                    print "Can not copy $keyfile...\n";
                    die;
                }
            }

            $inputtemp = tempnam(sys_get_temp_dir(), $filename);

            if (!copy($inputfile, $inputtemp)) 
            {
                print "Can not copy $inputfile...\n";
                die;
            }

            ShowForm();
        }
        else
        {
            print "Input file is not provided";
        }
    }
?>