<?php 
    date_default_timezone_set("UTC");

    $sig = new TElCMSSignature(NULL);
    $processor;
    $log = new TStringList();

    function CertValidityToStr($V)
    {
        switch ($V) {
            case TSBCertificateValidity::cvOk : Return 'OK'; break;
            case TSBCertificateValidity::cvSelfSigned : Return 'Self-signed'; break;
            case TSBCertificateValidity::cvInvalid : Return 'Invalid'; break;
            case TSBCertificateValidity::cvStorageError : Return 'Storage error'; break;
            case TSBCertificateValidity::cvChainUnvalidated : Return 'Chain unvalidated'; break;
            default: Return 'Unknown';
        }
    }

    function DoAfterCertificateValidation($Sender, $Certificate, $CACertificate, &$Validity, &$Reason, &$DoContinue)
    {
        global $log;
        $log->Add("Validation done. validity: " . CertValidityToStr($Validity));
    }

    function DoCertValidatorPrepared($Sender, &$CertValidator, $Cert)
    {
        global $log;
        $log->Add("Certificate validator prepared for validation of " . $Cert->get_SubjectRDN()->SaveToDNString());
        $CertValidator->OnAfterCertificateValidation = 'DoAfterCertificateValidation';
        $CertValidator->set_MandatoryCRLCheck(false);
        $CertValidator->set_MandatoryOCSPCheck(false);
        $CertValidator->set_MandatoryRevocationCheck(true);
    }

    function DoCertValidatorFinished($Sender, $CertValidator, $Cert, $Validity, $Reason)
    {
        global $log;
        $log->Add("Certificate validator finished validating " . $Cert->get_SubjectRDN()->SaveToDNString() . ": validity: " . CertValidityToStr($Validity));
    }
    function ShowForm()
    {
        global $log;
        global $sig;
        global $processor;

        echo '<html>';
        echo '<head>';
        echo '  <title>EldoS CAdES demo</title>';
        echo '  <style type="text/css">';
        echo '  .textheader {';
        echo '    font-family: Arial;';
        echo '    font-size: 16;';
        echo '    font-weight: bold;';
        echo '  }';
        echo '  .textnormal {';
        echo '    font-family: Arial;';
        echo '    font-size: 12;';
        echo '  }';
        echo '  </style>';
        echo '</head>';
        echo '<body>';
        echo '  <div align="center">';
        echo '  <table border="0" cellspacing="0" cellpadding="0" width="600" height="100%">';
        echo '    <tr height="*"></tr>';
        echo '    <tr height="400">';
        echo '      <td width="600" valign="top">';
        echo '        <table border="0" cellspacing="0" cellpadding="10" width="100%" height="100%" style="border: 1px solid #bbbbbb;" bgcolor="#f6f6f6">';
        echo '          <tr height="50">';
        echo '            <td width="100%" valign="center" bgcolor="#e6e6e6">';
        echo '              <div align="center" class="textheader">EldoS SecureBlackbox CAdES demo</div>';
        echo '            </td>';
        echo '          </tr>';
        echo '          <tr height="70">';
        echo '            <td width="100%" height="*" align="center" valign="center" class="textnormal">';
        echo '              <div align="center"> This sample illustrates the use of SecureBlackbox CAdES components. </div>';
        echo '            </td>';
        echo '          </tr>';
        echo '          <tr height="*">';
        echo '            <td width="100%" height="*">';
        echo '              <form action="PAdES.php" method="post" enctype="multipart/form-data">';
        echo '                <table border="0" cellspacing="0" cellpadding="0" width="100%" height="100%" class="textnormal">';
        echo '                  <tr height="30" valign="bottom">';
        echo '                    <td width="30%" align="left"> <span class="mtx4">Signature properties:</span> </td>';
        echo '                    <td width="10"></td>';
        echo '                    <td width="*" align="right"></td>';
        echo '                  </tr>';
        echo '                  <tr height="70" valign="bottom">';
        echo '                    <td colspan="3" align="left">';
        echo '                      <table border class="textnormal">';
        echo '                       <tr> <th width="100"> Property </th>  <th width="500"> Value </th> </tr>';
        echo '                       <tr> <td> Signer </td>  <td> Issure: ' . $sig->get_Signer()->get_Issuer()->SaveToDNString() . 
             ', serial: ' . SBUtils\BinaryToString($sig->get_Signer()->get_SerialNumber()) . ' </td> </tr>';
        echo '                       <tr> <td> Digest algorithm </td>  <td> ' . SBConstants\GetAlgorithmNameByAlgorithm($sig->get_DigestAlgorithm()) . ' </td> </tr>';

        $s = "";
        if ($processor->IsBES())
        {
            $s = $s . 'BES, ';
        }
        if ($processor->IsEPES())
        {
            $s = $s . 'EPES, ';
        }
        if ($processor->IsT())
        {
            $s = $s . 'T, ';
        }
        if ($processor->IsC())
        {
            $s = $s . 'C, ';
        }
        if ($processor->IsXType1())
        {
            $s = $s . 'X-Type-1, ';
        }
        if ($processor->IsXType2())
        {
            $s = $s . 'X-Type-2, ';
        }
        if ($processor->IsXLType1())
        {
            $s = $s . 'XL-Type-1, ';
        }
        if ($processor->IsXLType2())
        {
            $s = $s . 'XL-Type-2, ';
        }
        if ($processor->IsA())
        {
            $s = $s . 'A, ';
        }

        if ($s == "")
        {
            $s = 'Not a CAdES signature';
        }
        else
        {
            $s = substr($s, 0, strlen($s) - 2) ;
        }

        echo '                       <tr> <td> Signature levels </td>  <td> ' . $s . ' </td> </tr>';
        if ($processor->get_ClaimedSigningTime()->format('d-m-Y H:i:s') == '30-12-1899 00:00:00')
        {
            echo '                       <tr> <td> Claimed signing time </td>  <td> N/A </td> </tr>';
        }
        else
        {
            echo '                       <tr> <td> Claimed signing time </td>  <td> ' . $processor->get_ClaimedSigningTime()->format('d-m-Y H:i:s') . ' </td> </tr>';
        }
        if ($processor->get_CertifiedSigningTime()->format('d-m-Y H:i:s') == '30-12-1899 00:00:00')
        {
            echo '                       <tr> <td> Certified signing time </td>  <td> N/A </td> </tr>';
        }
        else
        {
            echo '                       <tr> <td> Certified signing time </td>  <td> ' . $processor->get_CertifiedSigningTime()->format('d-m-Y H:i:s') . ' </td> </tr>';
        }
        if ($processor->get_LastArchivalTime()->format('d-m-Y H:i:s') == '30-12-1899 00:00:00')
        {
            echo '                       <tr> <td> Last archival time </td>  <td> N/A </td> </tr>';
        }
        else
        {
            echo '                       <tr> <td> Last archival time </td>  <td> ' . $processor->get_LastArchivalTime()->format('d-m-Y H:i:s') . ' </td> </tr>';
        }
        if ($processor->get_CertifiedValidationTime()->format('d-m-Y H:i:s') == '30-12-1899 00:00:00')
        {
            echo '                       <tr> <td> Certified validation time </td>  <td> N/A </td> </tr>';
        }
        else
        {
            echo '                       <tr> <td> Certified validation time </td>  <td> ' . $processor->get_CertifiedValidationTime()->format('d-m-Y H:i:s') . ' </td> </tr>';
        }
        echo '                      </table>';
        echo '                    </td>';
        echo '                  </tr>';
        echo '                  <tr height="30" valign="bottom">';
        echo '                    <td width="*" align="left"> <span class="mtx4">Logs:</span> </td>';
        echo '                    <td width="10"></td>';
        echo '                    <td width="30" align="right"></td>';
        echo '                  </tr>';
        echo '                  <tr height="50">';
        echo '                    <td colspan="3" align="center">';
        echo '                      <textarea readonly name="info" cols=90 rows=10>';

        for ($i = 0; $i <= $log->Count - 1; $i++)
        {
            echo $log->get_Strings($i) . "\r\n";
        }

        echo '                      </textarea>';
        echo '                    </td>';
        echo '                  </tr>';
        echo '                  <tr height="30" valign="bottom">';
        echo '                    <td colspan="3" align="center"> Please inspect the source code of this script for more details. </td>';
        echo '                  </tr>';
        echo '                </table>';
        echo '              </form>';
        echo '            </td>';
        echo '          </tr>';
        echo '          <tr height="20">';
        echo '            <td width="100%" valign="center" bgcolor="#e6e6e6">';
        echo '              <div align="center" class="textnormal">Copyright &copy; EldoS Corporation <a href="http://www.eldos.com/">www.eldos.com</a></div>';
        echo '            </td>';
        echo '          </tr>';
        echo '        </table>';
        echo '      </td>';
        echo '    </tr>';
        echo '    <tr height="*"></tr>';
        echo '  </table>';
        echo '  </div>';
        echo '</body>';
        echo '</html>';
    }

    if (isset($_POST["validate"])) 
    {
        if (!extension_loaded("sbb") && !function_exists('SBUtils\SetLicenseKey')) 
        {
            print "SecureBlackbox extension is not available, please check that you've set it up correctly";
            die;
        }

        $inputfile = $_FILES["inputfile"]["tmp_name"];
        $filename = $_FILES["inputfile"]["name"];

        if (strlen($inputfile) > 0)
        {
            $in = new TMemoryStream;

            $in->LoadFromFile($inputfile);

            try
            {
                $cms = new TElSignedCMSMessage(NULL);
                $cms->Open($in, NULL, $in->Size, 0);

                if ($cms->SignatureCount > 0)
                {
                    $sig = $cms->get_Signatures(0);
                    $processor = new TElCAdESSignatureProcessor($sig);
                    $processor->OnCertValidatorPrepared = 'DoCertValidatorPrepared';
                    $processor->OnCertValidatorFinished = 'DoCertValidatorFinished';
                    $processor->set_IgnoreChainValidationErrors(false);

                    $valid = $processor->Validate();
                    $log->Add('');
                    if ($valid == TSBCAdESSignatureValidity::asvValid)
                    {
                        $log->Add('Validation succeeded');
                    }
                    else if ($valid == TSBCAdESSignatureValidity::asvInvalid)
                    {
                        $log->Add('Signature is invalid');
                    }
                    else
                    {
                        $log->Add('Validation incomplete (some pieces of validation information are likely to be missing)');
                    }

                    ShowForm();
                }
                else
                {
                    print "No signatures found. Validation cannot be done";
                }
            }
            catch(SBException $e) 
            {
                print $e->getMessage();
            }
        }
        else
        {
            print "File is not provided";
        }
    }
?>